@@ -8,13 +8,15 @@
 
 ;;; work around sbcl's obnoxious stadnard compliance
 
-(defmacro defconst (name value &optional doc)
-  `(eval-when (:compile-toplevel :load-toplevel :execute)
-     (unless (boundp ',name)
-       (defconstant ,name ,value ,doc))))
+(defmacro defconst (name value &optional (doc ""))
+   `(eval-when (:compile-toplevel :load-toplevel :execute)
+      (unless (boundp ',name)
+        ,(if doc
+             `(defconstant ,name ,value ,doc)
+           `(defconstant ,name ,value)))))
 
 (defconst +clause-names+
-  '(initially after-each finally if-first-time
+  '(initially after-each finally else if-first-time
     finally-protected
     finish leave next-iteration next terminate
     repeat for as generate generating in
@@ -25,4 +27,6 @@
     nunioning unioning reducing accumulate accumulating))
 
 (dolist (clause +clause-names+)
-  (export clause '#:iterate))
\ No newline at end of file
+  (export clause '#:iterate))
+
+;;; arch-tag: "b8bb0bb6-313c-11d8-abb9-000c76244c24"
